# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import typing_extensions
from typing import Mapping, cast

import httpx

from ...._types import (
    Body,
    Query,
    Headers,
    NotGiven,
    FileTypes,
    SequenceNotStr,
    not_given,
)
from ...._utils import extract_files, path_template, maybe_transform, deepcopy_minimal
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....pagination import SyncSinglePage, AsyncSinglePage
from ...._base_client import AsyncPaginator, make_request_options
from ....types.radar.ai import to_markdown_create_params
from ....types.radar.ai.to_markdown_create_response import ToMarkdownCreateResponse

__all__ = ["ToMarkdownResource", "AsyncToMarkdownResource"]


class ToMarkdownResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ToMarkdownResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return ToMarkdownResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ToMarkdownResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return ToMarkdownResourceWithStreamingResponse(self)

    @typing_extensions.deprecated(
        "Use [AI > To Markdown](https://developers.cloudflare.com/api/resources/ai/subresources/to_markdown/) instead."
    )
    def create(
        self,
        *,
        account_id: str,
        files: SequenceNotStr[FileTypes],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncSinglePage[ToMarkdownCreateResponse]:
        """
        Converts uploaded files into Markdown format using Workers AI.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        body = deepcopy_minimal({"files": files})
        extracted_files = extract_files(cast(Mapping[str, object], body), paths=[["files", "<array>"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return self._get_api_list(  # type: ignore[call-arg]
            path_template("/accounts/{account_id}/ai/tomarkdown", account_id=account_id),
            page=SyncSinglePage[ToMarkdownCreateResponse],
            body=maybe_transform(body, to_markdown_create_params.ToMarkdownCreateParams),
            files=extracted_files,  # pyright: ignore[reportCallIssue]
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=ToMarkdownCreateResponse,
            method="post",
        )


class AsyncToMarkdownResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncToMarkdownResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncToMarkdownResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncToMarkdownResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncToMarkdownResourceWithStreamingResponse(self)

    @typing_extensions.deprecated(
        "Use [AI > To Markdown](https://developers.cloudflare.com/api/resources/ai/subresources/to_markdown/) instead."
    )
    def create(
        self,
        *,
        account_id: str,
        files: SequenceNotStr[FileTypes],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[ToMarkdownCreateResponse, AsyncSinglePage[ToMarkdownCreateResponse]]:
        """
        Converts uploaded files into Markdown format using Workers AI.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        body = deepcopy_minimal({"files": files})
        extracted_files = extract_files(cast(Mapping[str, object], body), paths=[["files", "<array>"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return self._get_api_list(  # type: ignore[call-arg]
            path_template("/accounts/{account_id}/ai/tomarkdown", account_id=account_id),
            page=AsyncSinglePage[ToMarkdownCreateResponse],
            body=maybe_transform(body, to_markdown_create_params.ToMarkdownCreateParams),
            files=extracted_files,  # pyright: ignore[reportCallIssue]
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=ToMarkdownCreateResponse,
            method="post",
        )


class ToMarkdownResourceWithRawResponse:
    def __init__(self, to_markdown: ToMarkdownResource) -> None:
        self._to_markdown = to_markdown

        self.create = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                to_markdown.create,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncToMarkdownResourceWithRawResponse:
    def __init__(self, to_markdown: AsyncToMarkdownResource) -> None:
        self._to_markdown = to_markdown

        self.create = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                to_markdown.create,  # pyright: ignore[reportDeprecated],
            )
        )


class ToMarkdownResourceWithStreamingResponse:
    def __init__(self, to_markdown: ToMarkdownResource) -> None:
        self._to_markdown = to_markdown

        self.create = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                to_markdown.create,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncToMarkdownResourceWithStreamingResponse:
    def __init__(self, to_markdown: AsyncToMarkdownResource) -> None:
        self._to_markdown = to_markdown

        self.create = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                to_markdown.create,  # pyright: ignore[reportDeprecated],
            )
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal, Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["DeploymentCreateParams", "Version", "Annotations"]


class DeploymentCreateParams(TypedDict, total=False):
    account_id: Required[str]
    """Identifier."""

    strategy: Required[Literal["percentage"]]

    versions: Required[Iterable[Version]]

    force: bool
    """
    If set to true, the deployment will be created even if normally blocked by
    something such rolling back to an older version when a secret has changed.
    """

    annotations: Annotations


class Version(TypedDict, total=False):
    percentage: Required[float]

    version_id: Required[str]


class Annotations(TypedDict, total=False):
    workers_message: Annotated[str, PropertyInfo(alias="workers/message")]
    """Human-readable message about the deployment. Truncated to 1000 bytes if longer."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .report_list_params import ReportListParams as ReportListParams
from .report_list_response import ReportListResponse as ReportListResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["Stage"]


class Stage(BaseModel):
    """The status of the deployment."""

    ended_on: Optional[datetime] = None
    """When the stage ended."""

    name: Literal["queued", "initialize", "clone_repo", "build", "deploy"]
    """The current build stage."""

    started_on: Optional[datetime] = None
    """When the stage started."""

    status: Literal["success", "idle", "active", "failure", "canceled"]
    """State of the current stage."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["InstanceSearchResponse", "Chunk", "ChunkItem", "ChunkScoringDetails"]


class ChunkItem(BaseModel):
    key: str

    metadata: Optional[Dict[str, object]] = None

    timestamp: Optional[float] = None


class ChunkScoringDetails(BaseModel):
    fusion_method: Optional[Literal["rrf", "max"]] = None

    keyword_rank: Optional[float] = None

    keyword_score: Optional[float] = None

    reranking_score: Optional[float] = None

    vector_rank: Optional[float] = None

    vector_score: Optional[float] = None


class Chunk(BaseModel):
    id: str

    score: float

    text: str

    type: str

    item: Optional[ChunkItem] = None

    scoring_details: Optional[ChunkScoringDetails] = None


class InstanceSearchResponse(BaseModel):
    chunks: List[Chunk]

    search_query: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal, TypeAlias

from ..._models import BaseModel

__all__ = ["ScanBulkCreateResponse", "ScanBulkCreateResponseItem", "ScanBulkCreateResponseItemOptions"]


class ScanBulkCreateResponseItemOptions(BaseModel):
    useragent: Optional[str] = None


class ScanBulkCreateResponseItem(BaseModel):
    api: str
    """URL to api report."""

    result: str
    """URL to report."""

    url: str
    """Submitted URL"""

    uuid: str
    """Scan ID."""

    visibility: Literal["public", "unlisted"]
    """Submitted visibility status."""

    options: Optional[ScanBulkCreateResponseItemOptions] = None


ScanBulkCreateResponse: TypeAlias = List[ScanBulkCreateResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

from ...._types import SequenceNotStr

__all__ = ["OperationListParams"]


class OperationListParams(TypedDict, total=False):
    zone_id: Required[str]
    """Identifier."""

    diff: bool
    """
    When `true`, only return API Discovery results that are not saved into API
    Shield Endpoint Management
    """

    direction: Literal["asc", "desc"]
    """Direction to order results."""

    endpoint: str
    """Filter results to only include endpoints containing this pattern."""

    host: SequenceNotStr[str]
    """Filter results to only include the specified hosts."""

    method: SequenceNotStr[str]
    """Filter results to only include the specified HTTP methods."""

    order: Literal["host", "method", "endpoint", "traffic_stats.requests", "traffic_stats.last_updated"]
    """Field to order by"""

    origin: Literal["ML", "SessionIdentifier", "LabelDiscovery"]
    """
    Filter results to only include discovery results sourced from a particular
    discovery engine

    - `ML` - Discovered operations that were sourced using ML API Discovery
    - `SessionIdentifier` - Discovered operations that were sourced using Session
      Identifier API Discovery
    """

    page: int
    """Page number of paginated results."""

    per_page: int
    """Maximum number of results per page."""

    state: Literal["review", "saved", "ignored"]
    """Filter results to only include discovery results in a particular state.

    States are as follows

    - `review` - Discovered operations that are not saved into API Shield Endpoint
      Management
    - `saved` - Discovered operations that are already saved into API Shield
      Endpoint Management
    - `ignored` - Discovered operations that have been marked as ignored
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .quota import (
    QuotaResource,
    AsyncQuotaResource,
    QuotaResourceWithRawResponse,
    AsyncQuotaResourceWithRawResponse,
    QuotaResourceWithStreamingResponse,
    AsyncQuotaResourceWithStreamingResponse,
)
from .certificate_packs import (
    CertificatePacksResource,
    AsyncCertificatePacksResource,
    CertificatePacksResourceWithRawResponse,
    AsyncCertificatePacksResourceWithRawResponse,
    CertificatePacksResourceWithStreamingResponse,
    AsyncCertificatePacksResourceWithStreamingResponse,
)

__all__ = [
    "QuotaResource",
    "AsyncQuotaResource",
    "QuotaResourceWithRawResponse",
    "AsyncQuotaResourceWithRawResponse",
    "QuotaResourceWithStreamingResponse",
    "AsyncQuotaResourceWithStreamingResponse",
    "CertificatePacksResource",
    "AsyncCertificatePacksResource",
    "CertificatePacksResourceWithRawResponse",
    "AsyncCertificatePacksResourceWithRawResponse",
    "CertificatePacksResourceWithStreamingResponse",
    "AsyncCertificatePacksResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from ....._types import FileTypes

__all__ = ["ItemUploadParams", "File"]


class ItemUploadParams(TypedDict, total=False):
    account_id: Required[str]

    name: Required[str]

    file: Required[File]


class File(TypedDict, total=False):
    file: Required[FileTypes]
    """The file to upload (max 4MB). Filename must not exceed 128 characters."""

    metadata: str
    """JSON string of custom metadata key-value pairs."""

    wait_for_completion: bool
    """Wait for indexing to fully complete before responding.

    On RAGs with vector indexing enabled, this additionally waits for Vectorize
    ingestion confirmation (up to 40s) so the returned item reflects a queryable
    state. On timeout the item is returned in `running` state and the background
    alarm continues polling. Defaults to false.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .acl import ACL as ACL
from .peer import Peer as Peer
from .tsig import TSIG as TSIG
from .force_axfr import ForceAXFR as ForceAXFR
from .enable_transfer import EnableTransfer as EnableTransfer
from .outgoing_status import OutgoingStatus as OutgoingStatus
from .disable_transfer import DisableTransfer as DisableTransfer
from .acl_create_params import ACLCreateParams as ACLCreateParams
from .acl_update_params import ACLUpdateParams as ACLUpdateParams
from .peer_create_params import PeerCreateParams as PeerCreateParams
from .peer_update_params import PeerUpdateParams as PeerUpdateParams
from .tsig_create_params import TSIGCreateParams as TSIGCreateParams
from .tsig_update_params import TSIGUpdateParams as TSIGUpdateParams
from .acl_delete_response import ACLDeleteResponse as ACLDeleteResponse
from .peer_delete_response import PeerDeleteResponse as PeerDeleteResponse
from .tsig_delete_response import TSIGDeleteResponse as TSIGDeleteResponse
from .incoming_get_response import IncomingGetResponse as IncomingGetResponse
from .outgoing_get_response import OutgoingGetResponse as OutgoingGetResponse
from .incoming_create_params import IncomingCreateParams as IncomingCreateParams
from .incoming_update_params import IncomingUpdateParams as IncomingUpdateParams
from .outgoing_create_params import OutgoingCreateParams as OutgoingCreateParams
from .outgoing_enable_params import OutgoingEnableParams as OutgoingEnableParams
from .outgoing_update_params import OutgoingUpdateParams as OutgoingUpdateParams
from .outgoing_disable_params import OutgoingDisableParams as OutgoingDisableParams
from .force_axfr_create_params import ForceAXFRCreateParams as ForceAXFRCreateParams
from .incoming_create_response import IncomingCreateResponse as IncomingCreateResponse
from .incoming_delete_response import IncomingDeleteResponse as IncomingDeleteResponse
from .incoming_update_response import IncomingUpdateResponse as IncomingUpdateResponse
from .outgoing_create_response import OutgoingCreateResponse as OutgoingCreateResponse
from .outgoing_delete_response import OutgoingDeleteResponse as OutgoingDeleteResponse
from .outgoing_update_response import OutgoingUpdateResponse as OutgoingUpdateResponse
from .outgoing_force_notify_params import OutgoingForceNotifyParams as OutgoingForceNotifyParams
from .outgoing_force_notify_response import OutgoingForceNotifyResponse as OutgoingForceNotifyResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["Phase"]

Phase: TypeAlias = Literal[
    "ddos_l4",
    "ddos_l7",
    "http_config_settings",
    "http_custom_errors",
    "http_log_custom_fields",
    "http_ratelimit",
    "http_request_cache_settings",
    "http_request_dynamic_redirect",
    "http_request_firewall_custom",
    "http_request_firewall_managed",
    "http_request_late_transform",
    "http_request_origin",
    "http_request_redirect",
    "http_request_sanitize",
    "http_request_sbfm",
    "http_request_transform",
    "http_response_cache_settings",
    "http_response_compression",
    "http_response_firewall_managed",
    "http_response_headers_transform",
    "magic_transit",
    "magic_transit_ids_managed",
    "magic_transit_managed",
    "magic_transit_ratelimit",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from ...._models import BaseModel
from ..buckets.provider import Provider

__all__ = [
    "JobListResponse",
    "Source",
    "SourceS3SourceResponseSchema",
    "SourceGcsSourceResponseSchema",
    "SourceR2SourceResponseSchema",
    "Target",
]


class SourceS3SourceResponseSchema(BaseModel):
    bucket: Optional[str] = None

    endpoint: Optional[str] = None

    keys: Optional[List[str]] = None

    path_prefix: Optional[str] = FieldInfo(alias="pathPrefix", default=None)

    vendor: Optional[Literal["s3"]] = None


class SourceGcsSourceResponseSchema(BaseModel):
    bucket: Optional[str] = None

    keys: Optional[List[str]] = None

    path_prefix: Optional[str] = FieldInfo(alias="pathPrefix", default=None)

    vendor: Optional[Literal["gcs"]] = None


class SourceR2SourceResponseSchema(BaseModel):
    bucket: Optional[str] = None

    jurisdiction: Optional[Literal["default", "eu", "fedramp"]] = None

    keys: Optional[List[str]] = None

    path_prefix: Optional[str] = FieldInfo(alias="pathPrefix", default=None)

    vendor: Optional[Provider] = None


Source: TypeAlias = Union[SourceS3SourceResponseSchema, SourceGcsSourceResponseSchema, SourceR2SourceResponseSchema]


class Target(BaseModel):
    bucket: Optional[str] = None

    jurisdiction: Optional[Literal["default", "eu", "fedramp"]] = None

    vendor: Optional[Provider] = None


class JobListResponse(BaseModel):
    id: Optional[str] = None

    created_at: Optional[str] = FieldInfo(alias="createdAt", default=None)

    finished_at: Optional[str] = FieldInfo(alias="finishedAt", default=None)

    overwrite: Optional[bool] = None

    source: Optional[Source] = None

    status: Optional[Literal["running", "paused", "aborted", "completed"]] = None

    target: Optional[Target] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, Iterable, Optional, cast
from typing_extensions import Literal

import httpx

from ....._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ....._utils import path_template, maybe_transform, async_maybe_transform
from ....._compat import cached_property
from .integrations import (
    IntegrationsResource,
    AsyncIntegrationsResource,
    IntegrationsResourceWithRawResponse,
    AsyncIntegrationsResourceWithRawResponse,
    IntegrationsResourceWithStreamingResponse,
    AsyncIntegrationsResourceWithStreamingResponse,
)
from ....._resource import SyncAPIResource, AsyncAPIResource
from ....._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....._wrappers import ResultWrapper
from .....pagination import SyncSinglePage, AsyncSinglePage
from ....._base_client import AsyncPaginator, make_request_options
from .....types.zero_trust.devices import posture_create_params, posture_update_params
from .....types.zero_trust.devices.device_input_param import DeviceInputParam
from .....types.zero_trust.devices.device_match_param import DeviceMatchParam
from .....types.zero_trust.devices.device_posture_rule import DevicePostureRule
from .....types.zero_trust.devices.posture_delete_response import PostureDeleteResponse

__all__ = ["PostureResource", "AsyncPostureResource"]


class PostureResource(SyncAPIResource):
    @cached_property
    def integrations(self) -> IntegrationsResource:
        return IntegrationsResource(self._client)

    @cached_property
    def with_raw_response(self) -> PostureResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return PostureResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PostureResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return PostureResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        account_id: str,
        name: str,
        type: Literal[
            "file",
            "application",
            "tanium",
            "gateway",
            "warp",
            "disk_encryption",
            "serial_number",
            "sentinelone",
            "carbonblack",
            "firewall",
            "os_version",
            "domain_joined",
            "client_certificate",
            "client_certificate_v2",
            "antivirus",
            "unique_client_id",
            "kolide",
            "tanium_s2s",
            "crowdstrike_s2s",
            "intune",
            "workspace_one",
            "sentinelone_s2s",
            "custom_s2s",
        ],
        description: str | Omit = omit,
        expiration: str | Omit = omit,
        input: DeviceInputParam | Omit = omit,
        match: Iterable[DeviceMatchParam] | Omit = omit,
        schedule: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[DevicePostureRule]:
        """
        Creates a new device posture rule.

        Args:
          name: The name of the device posture rule.

          type: The type of device posture rule.

          description: The description of the device posture rule.

          expiration: Sets the expiration time for a posture check result. If empty, the result
              remains valid until it is overwritten by new data from the WARP client.

          input: The value to be checked against.

          match: The conditions that the client must match to run the rule.

          schedule: Polling frequency for the WARP client posture check. Default: `5m` (poll every
              five minutes). Minimum: `1m`.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._post(
            path_template("/accounts/{account_id}/devices/posture", account_id=account_id),
            body=maybe_transform(
                {
                    "name": name,
                    "type": type,
                    "description": description,
                    "expiration": expiration,
                    "input": input,
                    "match": match,
                    "schedule": schedule,
                },
                posture_create_params.PostureCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[DevicePostureRule]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[DevicePostureRule]], ResultWrapper[DevicePostureRule]),
        )

    def update(
        self,
        rule_id: str,
        *,
        account_id: str,
        name: str,
        type: Literal[
            "file",
            "application",
            "tanium",
            "gateway",
            "warp",
            "disk_encryption",
            "serial_number",
            "sentinelone",
            "carbonblack",
            "firewall",
            "os_version",
            "domain_joined",
            "client_certificate",
            "client_certificate_v2",
            "antivirus",
            "unique_client_id",
            "kolide",
            "tanium_s2s",
            "crowdstrike_s2s",
            "intune",
            "workspace_one",
            "sentinelone_s2s",
            "custom_s2s",
        ],
        description: str | Omit = omit,
        expiration: str | Omit = omit,
        input: DeviceInputParam | Omit = omit,
        match: Iterable[DeviceMatchParam] | Omit = omit,
        schedule: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[DevicePostureRule]:
        """
        Updates a device posture rule.

        Args:
          rule_id: API UUID.

          name: The name of the device posture rule.

          type: The type of device posture rule.

          description: The description of the device posture rule.

          expiration: Sets the expiration time for a posture check result. If empty, the result
              remains valid until it is overwritten by new data from the WARP client.

          input: The value to be checked against.

          match: The conditions that the client must match to run the rule.

          schedule: Polling frequency for the WARP client posture check. Default: `5m` (poll every
              five minutes). Minimum: `1m`.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not rule_id:
            raise ValueError(f"Expected a non-empty value for `rule_id` but received {rule_id!r}")
        return self._put(
            path_template("/accounts/{account_id}/devices/posture/{rule_id}", account_id=account_id, rule_id=rule_id),
            body=maybe_transform(
                {
                    "name": name,
                    "type": type,
                    "description": description,
                    "expiration": expiration,
                    "input": input,
                    "match": match,
                    "schedule": schedule,
                },
                posture_update_params.PostureUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[DevicePostureRule]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[DevicePostureRule]], ResultWrapper[DevicePostureRule]),
        )

    def list(
        self,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncSinglePage[DevicePostureRule]:
        """
        Fetches device posture rules for a Zero Trust account.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/devices/posture", account_id=account_id),
            page=SyncSinglePage[DevicePostureRule],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=DevicePostureRule,
        )

    def delete(
        self,
        rule_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[PostureDeleteResponse]:
        """
        Deletes a device posture rule.

        Args:
          rule_id: API UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not rule_id:
            raise ValueError(f"Expected a non-empty value for `rule_id` but received {rule_id!r}")
        return self._delete(
            path_template("/accounts/{account_id}/devices/posture/{rule_id}", account_id=account_id, rule_id=rule_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[PostureDeleteResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[PostureDeleteResponse]], ResultWrapper[PostureDeleteResponse]),
        )

    def get(
        self,
        rule_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[DevicePostureRule]:
        """
        Fetches a single device posture rule.

        Args:
          rule_id: API UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not rule_id:
            raise ValueError(f"Expected a non-empty value for `rule_id` but received {rule_id!r}")
        return self._get(
            path_template("/accounts/{account_id}/devices/posture/{rule_id}", account_id=account_id, rule_id=rule_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[DevicePostureRule]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[DevicePostureRule]], ResultWrapper[DevicePostureRule]),
        )


class AsyncPostureResource(AsyncAPIResource):
    @cached_property
    def integrations(self) -> AsyncIntegrationsResource:
        return AsyncIntegrationsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncPostureResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPostureResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPostureResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncPostureResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        account_id: str,
        name: str,
        type: Literal[
            "file",
            "application",
            "tanium",
            "gateway",
            "warp",
            "disk_encryption",
            "serial_number",
            "sentinelone",
            "carbonblack",
            "firewall",
            "os_version",
            "domain_joined",
            "client_certificate",
            "client_certificate_v2",
            "antivirus",
            "unique_client_id",
            "kolide",
            "tanium_s2s",
            "crowdstrike_s2s",
            "intune",
            "workspace_one",
            "sentinelone_s2s",
            "custom_s2s",
        ],
        description: str | Omit = omit,
        expiration: str | Omit = omit,
        input: DeviceInputParam | Omit = omit,
        match: Iterable[DeviceMatchParam] | Omit = omit,
        schedule: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[DevicePostureRule]:
        """
        Creates a new device posture rule.

        Args:
          name: The name of the device posture rule.

          type: The type of device posture rule.

          description: The description of the device posture rule.

          expiration: Sets the expiration time for a posture check result. If empty, the result
              remains valid until it is overwritten by new data from the WARP client.

          input: The value to be checked against.

          match: The conditions that the client must match to run the rule.

          schedule: Polling frequency for the WARP client posture check. Default: `5m` (poll every
              five minutes). Minimum: `1m`.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._post(
            path_template("/accounts/{account_id}/devices/posture", account_id=account_id),
            body=await async_maybe_transform(
                {
                    "name": name,
                    "type": type,
                    "description": description,
                    "expiration": expiration,
                    "input": input,
                    "match": match,
                    "schedule": schedule,
                },
                posture_create_params.PostureCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[DevicePostureRule]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[DevicePostureRule]], ResultWrapper[DevicePostureRule]),
        )

    async def update(
        self,
        rule_id: str,
        *,
        account_id: str,
        name: str,
        type: Literal[
            "file",
            "application",
            "tanium",
            "gateway",
            "warp",
            "disk_encryption",
            "serial_number",
            "sentinelone",
            "carbonblack",
            "firewall",
            "os_version",
            "domain_joined",
            "client_certificate",
            "client_certificate_v2",
            "antivirus",
            "unique_client_id",
            "kolide",
            "tanium_s2s",
            "crowdstrike_s2s",
            "intune",
            "workspace_one",
            "sentinelone_s2s",
            "custom_s2s",
        ],
        description: str | Omit = omit,
        expiration: str | Omit = omit,
        input: DeviceInputParam | Omit = omit,
        match: Iterable[DeviceMatchParam] | Omit = omit,
        schedule: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[DevicePostureRule]:
        """
        Updates a device posture rule.

        Args:
          rule_id: API UUID.

          name: The name of the device posture rule.

          type: The type of device posture rule.

          description: The description of the device posture rule.

          expiration: Sets the expiration time for a posture check result. If empty, the result
              remains valid until it is overwritten by new data from the WARP client.

          input: The value to be checked against.

          match: The conditions that the client must match to run the rule.

          schedule: Polling frequency for the WARP client posture check. Default: `5m` (poll every
              five minutes). Minimum: `1m`.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not rule_id:
            raise ValueError(f"Expected a non-empty value for `rule_id` but received {rule_id!r}")
        return await self._put(
            path_template("/accounts/{account_id}/devices/posture/{rule_id}", account_id=account_id, rule_id=rule_id),
            body=await async_maybe_transform(
                {
                    "name": name,
                    "type": type,
                    "description": description,
                    "expiration": expiration,
                    "input": input,
                    "match": match,
                    "schedule": schedule,
                },
                posture_update_params.PostureUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[DevicePostureRule]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[DevicePostureRule]], ResultWrapper[DevicePostureRule]),
        )

    def list(
        self,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[DevicePostureRule, AsyncSinglePage[DevicePostureRule]]:
        """
        Fetches device posture rules for a Zero Trust account.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/devices/posture", account_id=account_id),
            page=AsyncSinglePage[DevicePostureRule],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=DevicePostureRule,
        )

    async def delete(
        self,
        rule_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[PostureDeleteResponse]:
        """
        Deletes a device posture rule.

        Args:
          rule_id: API UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not rule_id:
            raise ValueError(f"Expected a non-empty value for `rule_id` but received {rule_id!r}")
        return await self._delete(
            path_template("/accounts/{account_id}/devices/posture/{rule_id}", account_id=account_id, rule_id=rule_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[PostureDeleteResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[PostureDeleteResponse]], ResultWrapper[PostureDeleteResponse]),
        )

    async def get(
        self,
        rule_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[DevicePostureRule]:
        """
        Fetches a single device posture rule.

        Args:
          rule_id: API UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not rule_id:
            raise ValueError(f"Expected a non-empty value for `rule_id` but received {rule_id!r}")
        return await self._get(
            path_template("/accounts/{account_id}/devices/posture/{rule_id}", account_id=account_id, rule_id=rule_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[DevicePostureRule]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[DevicePostureRule]], ResultWrapper[DevicePostureRule]),
        )


class PostureResourceWithRawResponse:
    def __init__(self, posture: PostureResource) -> None:
        self._posture = posture

        self.create = to_raw_response_wrapper(
            posture.create,
        )
        self.update = to_raw_response_wrapper(
            posture.update,
        )
        self.list = to_raw_response_wrapper(
            posture.list,
        )
        self.delete = to_raw_response_wrapper(
            posture.delete,
        )
        self.get = to_raw_response_wrapper(
            posture.get,
        )

    @cached_property
    def integrations(self) -> IntegrationsResourceWithRawResponse:
        return IntegrationsResourceWithRawResponse(self._posture.integrations)


class AsyncPostureResourceWithRawResponse:
    def __init__(self, posture: AsyncPostureResource) -> None:
        self._posture = posture

        self.create = async_to_raw_response_wrapper(
            posture.create,
        )
        self.update = async_to_raw_response_wrapper(
            posture.update,
        )
        self.list = async_to_raw_response_wrapper(
            posture.list,
        )
        self.delete = async_to_raw_response_wrapper(
            posture.delete,
        )
        self.get = async_to_raw_response_wrapper(
            posture.get,
        )

    @cached_property
    def integrations(self) -> AsyncIntegrationsResourceWithRawResponse:
        return AsyncIntegrationsResourceWithRawResponse(self._posture.integrations)


class PostureResourceWithStreamingResponse:
    def __init__(self, posture: PostureResource) -> None:
        self._posture = posture

        self.create = to_streamed_response_wrapper(
            posture.create,
        )
        self.update = to_streamed_response_wrapper(
            posture.update,
        )
        self.list = to_streamed_response_wrapper(
            posture.list,
        )
        self.delete = to_streamed_response_wrapper(
            posture.delete,
        )
        self.get = to_streamed_response_wrapper(
            posture.get,
        )

    @cached_property
    def integrations(self) -> IntegrationsResourceWithStreamingResponse:
        return IntegrationsResourceWithStreamingResponse(self._posture.integrations)


class AsyncPostureResourceWithStreamingResponse:
    def __init__(self, posture: AsyncPostureResource) -> None:
        self._posture = posture

        self.create = async_to_streamed_response_wrapper(
            posture.create,
        )
        self.update = async_to_streamed_response_wrapper(
            posture.update,
        )
        self.list = async_to_streamed_response_wrapper(
            posture.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            posture.delete,
        )
        self.get = async_to_streamed_response_wrapper(
            posture.get,
        )

    @cached_property
    def integrations(self) -> AsyncIntegrationsResourceWithStreamingResponse:
        return AsyncIntegrationsResourceWithStreamingResponse(self._posture.integrations)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["RegionListParams"]


class RegionListParams(TypedDict, total=False):
    account_id: Required[str]
    """Identifier."""

    country_code_a2: str
    """Two-letter alpha-2 country code followed in ISO 3166-1."""

    subdivision_code: str
    """Two-letter subdivision code followed in ISO 3166-2."""

    subdivision_code_a2: str
    """Two-letter subdivision code followed in ISO 3166-2."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Union, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from ....._models import BaseModel
from ..profiles.pattern import Pattern

__all__ = [
    "CustomListResponse",
    "UnionMember0",
    "UnionMember1",
    "UnionMember2",
    "UnionMember2Confidence",
    "UnionMember2Variant",
    "UnionMember2VariantUnionMember0",
    "UnionMember2VariantUnionMember1",
    "UnionMember3",
    "UnionMember4",
    "UnionMember5",
    "UnionMember6",
]


class UnionMember0(BaseModel):
    id: str

    created_at: datetime

    enabled: bool

    name: str

    pattern: Pattern

    type: Literal["custom"]

    updated_at: datetime

    description: Optional[str] = None

    profile_id: Optional[str] = None

    upload_status: Optional[Literal["empty", "uploading", "pending", "processing", "failed", "complete"]] = None


class UnionMember1(BaseModel):
    id: str

    created_at: datetime

    enabled: bool

    name: str

    type: Literal["custom_prompt_topic"]

    updated_at: datetime

    upload_status: Optional[Literal["empty", "uploading", "pending", "processing", "failed", "complete"]] = None


class UnionMember2Confidence(BaseModel):
    ai_context_available: bool
    """Indicates whether this entry has AI remote service validation."""

    available: bool
    """
    Indicates whether this entry has any form of validation that is not an AI remote
    service.
    """


class UnionMember2VariantUnionMember0(BaseModel):
    """A Predefined AI prompt classification topic entry."""

    topic_type: Literal["Intent", "Content"]

    type: Literal["PromptTopic"]

    description: Optional[str] = None
    """
    A customer-facing explanation of what this predefined AI prompt topic
    represents.
    """


class UnionMember2VariantUnionMember1(BaseModel):
    """A general predefined entry."""

    type: Literal["General"]

    description: Optional[str] = None
    """A customer-facing explanation of what this predefined entry represents."""


UnionMember2Variant: TypeAlias = Union[UnionMember2VariantUnionMember0, UnionMember2VariantUnionMember1]


class UnionMember2(BaseModel):
    id: str

    confidence: UnionMember2Confidence

    enabled: bool

    name: str

    type: Literal["predefined"]

    profile_id: Optional[str] = None

    upload_status: Optional[Literal["empty", "uploading", "pending", "processing", "failed", "complete"]] = None

    variant: Optional[UnionMember2Variant] = None
    """A Predefined AI prompt classification topic entry."""


class UnionMember3(BaseModel):
    id: str

    created_at: datetime

    enabled: bool

    name: str

    type: Literal["integration"]

    updated_at: datetime

    profile_id: Optional[str] = None

    upload_status: Optional[Literal["empty", "uploading", "pending", "processing", "failed", "complete"]] = None


class UnionMember4(BaseModel):
    id: str

    case_sensitive: bool
    """
    Only applies to custom word lists. Determines if the words should be matched in
    a case-sensitive manner Cannot be set to false if secret is true
    """

    created_at: datetime

    enabled: bool

    name: str

    secret: bool

    type: Literal["exact_data"]

    updated_at: datetime

    upload_status: Optional[Literal["empty", "uploading", "pending", "processing", "failed", "complete"]] = None


class UnionMember5(BaseModel):
    id: str

    created_at: datetime

    enabled: bool

    name: str

    type: Literal["document_fingerprint"]

    updated_at: datetime

    upload_status: Optional[Literal["empty", "uploading", "pending", "processing", "failed", "complete"]] = None


class UnionMember6(BaseModel):
    id: str

    created_at: datetime

    enabled: bool

    name: str

    type: Literal["word_list"]

    updated_at: datetime

    word_list: object

    profile_id: Optional[str] = None

    upload_status: Optional[Literal["empty", "uploading", "pending", "processing", "failed", "complete"]] = None


CustomListResponse: TypeAlias = Union[
    UnionMember0, UnionMember1, UnionMember2, UnionMember3, UnionMember4, UnionMember5, UnionMember6
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Any, Type, Optional, cast

import httpx

from ....._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ....._utils import path_template, maybe_transform, async_maybe_transform
from ....._compat import cached_property
from ....._resource import SyncAPIResource, AsyncAPIResource
from ....._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....._wrappers import ResultWrapper
from .....pagination import SyncSinglePage, AsyncSinglePage
from ....._base_client import AsyncPaginator, make_request_options
from .....types.zero_trust.dlp.entries import custom_create_params, custom_update_params
from .....types.zero_trust.dlp.profiles.pattern_param import PatternParam
from .....types.zero_trust.dlp.entries.custom_get_response import CustomGetResponse
from .....types.zero_trust.dlp.entries.custom_list_response import CustomListResponse
from .....types.zero_trust.dlp.entries.custom_create_response import CustomCreateResponse
from .....types.zero_trust.dlp.entries.custom_update_response import CustomUpdateResponse

__all__ = ["CustomResource", "AsyncCustomResource"]


class CustomResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> CustomResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return CustomResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CustomResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return CustomResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        account_id: str,
        enabled: bool,
        name: str,
        pattern: PatternParam,
        description: Optional[str] | Omit = omit,
        profile_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CustomCreateResponse]:
        """
        Creates a DLP custom entry.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._post(
            path_template("/accounts/{account_id}/dlp/entries", account_id=account_id),
            body=maybe_transform(
                {
                    "enabled": enabled,
                    "name": name,
                    "pattern": pattern,
                    "description": description,
                    "profile_id": profile_id,
                },
                custom_create_params.CustomCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[CustomCreateResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[CustomCreateResponse]], ResultWrapper[CustomCreateResponse]),
        )

    def update(
        self,
        entry_id: str,
        *,
        account_id: str,
        enabled: bool,
        name: str,
        pattern: PatternParam,
        description: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CustomUpdateResponse]:
        """
        Updates a DLP custom entry.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not entry_id:
            raise ValueError(f"Expected a non-empty value for `entry_id` but received {entry_id!r}")
        return self._put(
            path_template(
                "/accounts/{account_id}/dlp/entries/custom/{entry_id}", account_id=account_id, entry_id=entry_id
            ),
            body=maybe_transform(
                {
                    "enabled": enabled,
                    "name": name,
                    "pattern": pattern,
                    "description": description,
                },
                custom_update_params.CustomUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[CustomUpdateResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[CustomUpdateResponse]], ResultWrapper[CustomUpdateResponse]),
        )

    def list(
        self,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncSinglePage[CustomListResponse]:
        """
        Lists all DLP entries in an account.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/dlp/entries", account_id=account_id),
            page=SyncSinglePage[CustomListResponse],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=cast(Any, CustomListResponse),  # Union types cannot be passed in as arguments in the type system
        )

    def delete(
        self,
        entry_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Deletes a DLP custom entry.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not entry_id:
            raise ValueError(f"Expected a non-empty value for `entry_id` but received {entry_id!r}")
        return self._delete(
            path_template("/accounts/{account_id}/dlp/entries/{entry_id}", account_id=account_id, entry_id=entry_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[object]]._unwrapper,
            ),
            cast_to=cast(Type[object], ResultWrapper[object]),
        )

    def get(
        self,
        entry_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CustomGetResponse]:
        """
        Fetches a DLP entry by ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not entry_id:
            raise ValueError(f"Expected a non-empty value for `entry_id` but received {entry_id!r}")
        return cast(
            Optional[CustomGetResponse],
            self._get(
                path_template(
                    "/accounts/{account_id}/dlp/entries/{entry_id}", account_id=account_id, entry_id=entry_id
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    post_parser=ResultWrapper[Optional[CustomGetResponse]]._unwrapper,
                ),
                cast_to=cast(
                    Any, ResultWrapper[CustomGetResponse]
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )


class AsyncCustomResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncCustomResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncCustomResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCustomResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncCustomResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        account_id: str,
        enabled: bool,
        name: str,
        pattern: PatternParam,
        description: Optional[str] | Omit = omit,
        profile_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CustomCreateResponse]:
        """
        Creates a DLP custom entry.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._post(
            path_template("/accounts/{account_id}/dlp/entries", account_id=account_id),
            body=await async_maybe_transform(
                {
                    "enabled": enabled,
                    "name": name,
                    "pattern": pattern,
                    "description": description,
                    "profile_id": profile_id,
                },
                custom_create_params.CustomCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[CustomCreateResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[CustomCreateResponse]], ResultWrapper[CustomCreateResponse]),
        )

    async def update(
        self,
        entry_id: str,
        *,
        account_id: str,
        enabled: bool,
        name: str,
        pattern: PatternParam,
        description: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CustomUpdateResponse]:
        """
        Updates a DLP custom entry.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not entry_id:
            raise ValueError(f"Expected a non-empty value for `entry_id` but received {entry_id!r}")
        return await self._put(
            path_template(
                "/accounts/{account_id}/dlp/entries/custom/{entry_id}", account_id=account_id, entry_id=entry_id
            ),
            body=await async_maybe_transform(
                {
                    "enabled": enabled,
                    "name": name,
                    "pattern": pattern,
                    "description": description,
                },
                custom_update_params.CustomUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[CustomUpdateResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[CustomUpdateResponse]], ResultWrapper[CustomUpdateResponse]),
        )

    def list(
        self,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[CustomListResponse, AsyncSinglePage[CustomListResponse]]:
        """
        Lists all DLP entries in an account.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/dlp/entries", account_id=account_id),
            page=AsyncSinglePage[CustomListResponse],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=cast(Any, CustomListResponse),  # Union types cannot be passed in as arguments in the type system
        )

    async def delete(
        self,
        entry_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Deletes a DLP custom entry.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not entry_id:
            raise ValueError(f"Expected a non-empty value for `entry_id` but received {entry_id!r}")
        return await self._delete(
            path_template("/accounts/{account_id}/dlp/entries/{entry_id}", account_id=account_id, entry_id=entry_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[object]]._unwrapper,
            ),
            cast_to=cast(Type[object], ResultWrapper[object]),
        )

    async def get(
        self,
        entry_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CustomGetResponse]:
        """
        Fetches a DLP entry by ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not entry_id:
            raise ValueError(f"Expected a non-empty value for `entry_id` but received {entry_id!r}")
        return cast(
            Optional[CustomGetResponse],
            await self._get(
                path_template(
                    "/accounts/{account_id}/dlp/entries/{entry_id}", account_id=account_id, entry_id=entry_id
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    post_parser=ResultWrapper[Optional[CustomGetResponse]]._unwrapper,
                ),
                cast_to=cast(
                    Any, ResultWrapper[CustomGetResponse]
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )


class CustomResourceWithRawResponse:
    def __init__(self, custom: CustomResource) -> None:
        self._custom = custom

        self.create = to_raw_response_wrapper(
            custom.create,
        )
        self.update = to_raw_response_wrapper(
            custom.update,
        )
        self.list = to_raw_response_wrapper(
            custom.list,
        )
        self.delete = to_raw_response_wrapper(
            custom.delete,
        )
        self.get = to_raw_response_wrapper(
            custom.get,
        )


class AsyncCustomResourceWithRawResponse:
    def __init__(self, custom: AsyncCustomResource) -> None:
        self._custom = custom

        self.create = async_to_raw_response_wrapper(
            custom.create,
        )
        self.update = async_to_raw_response_wrapper(
            custom.update,
        )
        self.list = async_to_raw_response_wrapper(
            custom.list,
        )
        self.delete = async_to_raw_response_wrapper(
            custom.delete,
        )
        self.get = async_to_raw_response_wrapper(
            custom.get,
        )


class CustomResourceWithStreamingResponse:
    def __init__(self, custom: CustomResource) -> None:
        self._custom = custom

        self.create = to_streamed_response_wrapper(
            custom.create,
        )
        self.update = to_streamed_response_wrapper(
            custom.update,
        )
        self.list = to_streamed_response_wrapper(
            custom.list,
        )
        self.delete = to_streamed_response_wrapper(
            custom.delete,
        )
        self.get = to_streamed_response_wrapper(
            custom.get,
        )


class AsyncCustomResourceWithStreamingResponse:
    def __init__(self, custom: AsyncCustomResource) -> None:
        self._custom = custom

        self.create = async_to_streamed_response_wrapper(
            custom.create,
        )
        self.update = async_to_streamed_response_wrapper(
            custom.update,
        )
        self.list = async_to_streamed_response_wrapper(
            custom.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            custom.delete,
        )
        self.get = async_to_streamed_response_wrapper(
            custom.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, TypedDict

__all__ = ["PrioritizeUpdateParams", "Certificate"]


class PrioritizeUpdateParams(TypedDict, total=False):
    zone_id: Required[str]
    """Identifier."""

    certificates: Required[Iterable[Certificate]]
    """Array of ordered certificates."""


class Certificate(TypedDict, total=False):
    id: str
    """Identifier."""

    priority: float
    """The order/priority in which the certificate will be used in a request.

    The higher priority will break ties across overlapping 'legacy_custom'
    certificates, but 'legacy_custom' certificates will always supercede
    'sni_custom' certificates.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .lists import (
    ListsResource,
    AsyncListsResource,
    ListsResourceWithRawResponse,
    AsyncListsResourceWithRawResponse,
    ListsResourceWithStreamingResponse,
    AsyncListsResourceWithStreamingResponse,
)
from .rules import (
    RulesResource,
    AsyncRulesResource,
    RulesResourceWithRawResponse,
    AsyncRulesResourceWithRawResponse,
    RulesResourceWithStreamingResponse,
    AsyncRulesResourceWithStreamingResponse,
)

__all__ = [
    "ListsResource",
    "AsyncListsResource",
    "ListsResourceWithRawResponse",
    "AsyncListsResourceWithRawResponse",
    "ListsResourceWithStreamingResponse",
    "AsyncListsResourceWithStreamingResponse",
    "RulesResource",
    "AsyncRulesResource",
    "RulesResourceWithRawResponse",
    "AsyncRulesResourceWithRawResponse",
    "RulesResourceWithStreamingResponse",
    "AsyncRulesResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .summary_user_agent_params import SummaryUserAgentParams as SummaryUserAgentParams
from .summary_user_agent_response import SummaryUserAgentResponse as SummaryUserAgentResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["UserListParams"]


class UserListParams(TypedDict, total=False):
    account_id: Required[str]
    """Identifier."""

    page: int
    """Page number of results."""

    per_page: int

    status: Literal["success", "fail", "error"]
    """Filter users by their policy evaluation status."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["RocketLoader"]


class RocketLoader(BaseModel):
    id: Optional[Literal["rocket_loader"]] = None
    """Turn on or off Rocket Loader in the Cloudflare Speed app."""

    value: Optional[Literal["on", "off"]] = None
    """The status of Rocket Loader"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .scans import (
    ScansResource,
    AsyncScansResource,
    ScansResourceWithRawResponse,
    AsyncScansResourceWithRawResponse,
    ScansResourceWithStreamingResponse,
    AsyncScansResourceWithStreamingResponse,
)
from .config import (
    ConfigResource,
    AsyncConfigResource,
    ConfigResourceWithRawResponse,
    AsyncConfigResourceWithRawResponse,
    ConfigResourceWithStreamingResponse,
    AsyncConfigResourceWithStreamingResponse,
)
from .results import (
    ResultsResource,
    AsyncResultsResource,
    ResultsResourceWithRawResponse,
    AsyncResultsResourceWithRawResponse,
    ResultsResourceWithStreamingResponse,
    AsyncResultsResourceWithStreamingResponse,
)

__all__ = [
    "ResultsResource",
    "AsyncResultsResource",
    "ResultsResourceWithRawResponse",
    "AsyncResultsResourceWithRawResponse",
    "ResultsResourceWithStreamingResponse",
    "AsyncResultsResourceWithStreamingResponse",
    "ConfigResource",
    "AsyncConfigResource",
    "ConfigResourceWithRawResponse",
    "AsyncConfigResourceWithRawResponse",
    "ConfigResourceWithStreamingResponse",
    "AsyncConfigResourceWithStreamingResponse",
    "ScansResource",
    "AsyncScansResource",
    "ScansResourceWithRawResponse",
    "AsyncScansResourceWithRawResponse",
    "ScansResourceWithStreamingResponse",
    "AsyncScansResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["OriginCloudRegionDeleteResponse"]


class OriginCloudRegionDeleteResponse(BaseModel):
    """Response result for a delete operation. Identifies the deleted mapping."""

    origin_ip: str
    """The origin IP address whose mapping was deleted."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

from ..filters.firewall_filter_param import FirewallFilterParam

__all__ = ["RuleCreateParams", "Action", "ActionResponse"]


class RuleCreateParams(TypedDict, total=False):
    zone_id: Required[str]
    """Defines an identifier."""

    action: Required[Action]
    """
    The action to perform when the threshold of matched traffic within the
    configured period is exceeded.
    """

    filter: Required[FirewallFilterParam]


class ActionResponse(TypedDict, total=False):
    """A custom content type and reponse to return when the threshold is exceeded.

    The custom response configured in this object will override the custom error for the zone. This object is optional.
    Notes: If you omit this object, Cloudflare will use the default HTML error page. If "mode" is "challenge", "managed_challenge", or "js_challenge", Cloudflare will use the zone challenge pages and you should not provide the "response" object.
    """

    body: str
    """The response body to return.

    The value must conform to the configured content type.
    """

    content_type: str
    """The content type of the body.

    Must be one of the following: `text/plain`, `text/xml`, or `application/json`.
    """


class Action(TypedDict, total=False):
    """
    The action to perform when the threshold of matched traffic within the configured period is exceeded.
    """

    mode: Literal["simulate", "ban", "challenge", "js_challenge", "managed_challenge"]
    """The action to perform."""

    response: ActionResponse
    """A custom content type and reponse to return when the threshold is exceeded.

    The custom response configured in this object will override the custom error for
    the zone. This object is optional. Notes: If you omit this object, Cloudflare
    will use the default HTML error page. If "mode" is "challenge",
    "managed_challenge", or "js_challenge", Cloudflare will use the zone challenge
    pages and you should not provide the "response" object.
    """

    timeout: float
    """The time in seconds during which Cloudflare will perform the mitigation action.

    Must be an integer value greater than or equal to the period. Notes: If "mode"
    is "challenge", "managed_challenge", or "js_challenge", Cloudflare will use the
    zone's Challenge Passage time and you should not provide this value.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .language_update_params import LanguageUpdateParams as LanguageUpdateParams
from .language_delete_response import LanguageDeleteResponse as LanguageDeleteResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V1EditParams"]


class V1EditParams(TypedDict, total=False):
    account_id: Required[str]
    """Account identifier tag."""

    creator: str
    """Can set the creator field with an internal user ID."""

    metadata: object
    """User modifiable key-value store.

    Can be used for keeping references to another system of record for managing
    images. No change if not specified.
    """

    require_signed_urls: Annotated[bool, PropertyInfo(alias="requireSignedURLs")]
    """Indicates whether the image can be accessed using only its UID.

    If set to `true`, a signed token needs to be generated with a signing key to
    view the image. Returns a new UID on a change. No change if not specified.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Optional
from datetime import datetime
from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import path_template, maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.realtime_kit import (
    livestream_get_org_analytics_params,
    livestream_get_all_livestreams_params,
    livestream_create_independent_livestream_params,
    livestream_start_livestreaming_a_meeting_params,
    livestream_get_livestream_analytics_complete_params,
    livestream_get_livestream_session_for_livestream_id_params,
)
from ...types.realtime_kit.livestream_get_org_analytics_response import LivestreamGetOrgAnalyticsResponse
from ...types.realtime_kit.livestream_get_all_livestreams_response import LivestreamGetAllLivestreamsResponse
from ...types.realtime_kit.livestream_stop_livestreaming_a_meeting_response import (
    LivestreamStopLivestreamingAMeetingResponse,
)
from ...types.realtime_kit.livestream_create_independent_livestream_response import (
    LivestreamCreateIndependentLivestreamResponse,
)
from ...types.realtime_kit.livestream_start_livestreaming_a_meeting_response import (
    LivestreamStartLivestreamingAMeetingResponse,
)
from ...types.realtime_kit.livestream_get_meeting_active_livestreams_response import (
    LivestreamGetMeetingActiveLivestreamsResponse,
)
from ...types.realtime_kit.livestream_get_livestream_analytics_complete_response import (
    LivestreamGetLivestreamAnalyticsCompleteResponse,
)
from ...types.realtime_kit.livestream_get_active_livestreams_for_livestream_id_response import (
    LivestreamGetActiveLivestreamsForLivestreamIDResponse,
)
from ...types.realtime_kit.livestream_get_livestream_session_for_livestream_id_response import (
    LivestreamGetLivestreamSessionForLivestreamIDResponse,
)
from ...types.realtime_kit.livestream_get_livestream_session_details_for_session_id_response import (
    LivestreamGetLivestreamSessionDetailsForSessionIDResponse,
)

__all__ = ["LivestreamsResource", "AsyncLivestreamsResource"]


class LivestreamsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> LivestreamsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return LivestreamsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> LivestreamsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return LivestreamsResourceWithStreamingResponse(self)

    def create_independent_livestream(
        self,
        app_id: str,
        *,
        account_id: str,
        name: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamCreateIndependentLivestreamResponse:
        """
        Creates a livestream for the given App ID and returns ingest server, stream key,
        and playback URL. You can pass custom input to the ingest server and stream key,
        and freely distribute the content using the playback URL on any player that
        supports HLS/LHLS.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          name: Name of the livestream

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        return self._post(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/livestreams", account_id=account_id, app_id=app_id
            ),
            body=maybe_transform(
                {"name": name},
                livestream_create_independent_livestream_params.LivestreamCreateIndependentLivestreamParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LivestreamCreateIndependentLivestreamResponse,
        )

    def get_active_livestreams_for_livestream_id(
        self,
        livestream_id: str,
        *,
        account_id: str,
        app_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamGetActiveLivestreamsForLivestreamIDResponse:
        """Returns details of all active livestreams for the given livestream ID.

        Retreive
        the livestream ID using the `Start livestreaming a meeting` API.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        if not livestream_id:
            raise ValueError(f"Expected a non-empty value for `livestream_id` but received {livestream_id!r}")
        return self._get(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/livestreams/{livestream_id}/active-livestream-session",
                account_id=account_id,
                app_id=app_id,
                livestream_id=livestream_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LivestreamGetActiveLivestreamsForLivestreamIDResponse,
        )

    def get_all_livestreams(
        self,
        app_id: str,
        *,
        account_id: str,
        end_time: Union[str, datetime] | Omit = omit,
        exclude_meetings: bool | Omit = omit,
        page_no: int | Omit = omit,
        per_page: int | Omit = omit,
        sort_order: Literal["ASC", "DSC"] | Omit = omit,
        start_time: Union[str, datetime] | Omit = omit,
        status: Literal["LIVE", "IDLE", "ERRORED", "INVOKED"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamGetAllLivestreamsResponse:
        """Returns details of livestreams associated with the given App ID.

        It includes
        livestreams created by your App and RealtimeKit meetings that are livestreamed
        by your App. If you only want details of livestreams created by your App and not
        RealtimeKit meetings, you can use the `exclude_meetings` query parameter.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          end_time: Specify the end time range in ISO format to access the live stream.

          exclude_meetings: Exclude the RealtimeKit meetings that are livestreamed.

          page_no: The page number from which you want your page search results to be displayed.

          per_page: Number of results per page.

          sort_order: Specifies the sorting order for the results.

          start_time: Specify the start time range in ISO format to access the live stream.

          status: Specifies the status of the operation.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        return self._get(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/livestreams", account_id=account_id, app_id=app_id
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "end_time": end_time,
                        "exclude_meetings": exclude_meetings,
                        "page_no": page_no,
                        "per_page": per_page,
                        "sort_order": sort_order,
                        "start_time": start_time,
                        "status": status,
                    },
                    livestream_get_all_livestreams_params.LivestreamGetAllLivestreamsParams,
                ),
            ),
            cast_to=LivestreamGetAllLivestreamsResponse,
        )

    def get_livestream_analytics_complete(
        self,
        app_id: str,
        *,
        account_id: str,
        end_time: Union[str, datetime] | Omit = omit,
        start_time: Union[str, datetime] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamGetLivestreamAnalyticsCompleteResponse:
        """
        Returns livestream analytics for the specified time range.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          end_time: Specify the end time range in ISO format to access the livestream analytics.

          start_time: Specify the start time range in ISO format to access the livestream analytics.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        return self._get(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/analytics/livestreams/overall",
                account_id=account_id,
                app_id=app_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "end_time": end_time,
                        "start_time": start_time,
                    },
                    livestream_get_livestream_analytics_complete_params.LivestreamGetLivestreamAnalyticsCompleteParams,
                ),
            ),
            cast_to=LivestreamGetLivestreamAnalyticsCompleteResponse,
        )

    def get_livestream_session_details_for_session_id(
        self,
        livestream_session_id: str,
        *,
        account_id: str,
        app_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamGetLivestreamSessionDetailsForSessionIDResponse:
        """Returns livestream session details for the given livestream session ID.

        Retrieve
        the `livestream_session_id`using the
        `Fetch livestream session details using a session ID` API.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        if not livestream_session_id:
            raise ValueError(
                f"Expected a non-empty value for `livestream_session_id` but received {livestream_session_id!r}"
            )
        return self._get(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/livestreams/sessions/{livestream_session_id}",
                account_id=account_id,
                app_id=app_id,
                livestream_session_id=livestream_session_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LivestreamGetLivestreamSessionDetailsForSessionIDResponse,
        )

    def get_livestream_session_for_livestream_id(
        self,
        livestream_id: str,
        *,
        account_id: str,
        app_id: str,
        page_no: int | Omit = omit,
        per_page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamGetLivestreamSessionForLivestreamIDResponse:
        """
        Returns details of a livestream with sessions for the given livestream ID.
        Retreive the livestream ID using the `Start livestreaming a meeting` API.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          page_no: The page number from which you want your page search results to be displayed.

          per_page: Number of results per page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        if not livestream_id:
            raise ValueError(f"Expected a non-empty value for `livestream_id` but received {livestream_id!r}")
        return self._get(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/livestreams/{livestream_id}",
                account_id=account_id,
                app_id=app_id,
                livestream_id=livestream_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page_no": page_no,
                        "per_page": per_page,
                    },
                    livestream_get_livestream_session_for_livestream_id_params.LivestreamGetLivestreamSessionForLivestreamIDParams,
                ),
            ),
            cast_to=LivestreamGetLivestreamSessionForLivestreamIDResponse,
        )

    def get_meeting_active_livestreams(
        self,
        meeting_id: str,
        *,
        account_id: str,
        app_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamGetMeetingActiveLivestreamsResponse:
        """
        Returns details of all active livestreams for the given meeting ID.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        if not meeting_id:
            raise ValueError(f"Expected a non-empty value for `meeting_id` but received {meeting_id!r}")
        return self._get(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/meetings/{meeting_id}/active-livestream",
                account_id=account_id,
                app_id=app_id,
                meeting_id=meeting_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LivestreamGetMeetingActiveLivestreamsResponse,
        )

    def get_org_analytics(
        self,
        app_id: str,
        *,
        account_id: str,
        end_date: str | Omit = omit,
        start_date: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamGetOrgAnalyticsResponse:
        """
        Returns day-wise session and recording analytics data of an App for the
        specified time range start_date to end_date. If start_date and end_date are not
        provided, the default time range is set from 30 days ago to the current date.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          end_date: end date in YYYY-MM-DD format

          start_date: start date in YYYY-MM-DD format

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        return self._get(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/analytics/daywise", account_id=account_id, app_id=app_id
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "end_date": end_date,
                        "start_date": start_date,
                    },
                    livestream_get_org_analytics_params.LivestreamGetOrgAnalyticsParams,
                ),
            ),
            cast_to=LivestreamGetOrgAnalyticsResponse,
        )

    def start_livestreaming_a_meeting(
        self,
        meeting_id: str,
        *,
        account_id: str,
        app_id: str,
        name: Optional[str] | Omit = omit,
        video_config: livestream_start_livestreaming_a_meeting_params.VideoConfig | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamStartLivestreamingAMeetingResponse:
        """Starts livestream of a meeting associated with the given meeting ID.

        Retreive
        the meeting ID using the `Create a meeting` API.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        if not meeting_id:
            raise ValueError(f"Expected a non-empty value for `meeting_id` but received {meeting_id!r}")
        return self._post(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/meetings/{meeting_id}/livestreams",
                account_id=account_id,
                app_id=app_id,
                meeting_id=meeting_id,
            ),
            body=maybe_transform(
                {
                    "name": name,
                    "video_config": video_config,
                },
                livestream_start_livestreaming_a_meeting_params.LivestreamStartLivestreamingAMeetingParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LivestreamStartLivestreamingAMeetingResponse,
        )

    def stop_livestreaming_a_meeting(
        self,
        meeting_id: str,
        *,
        account_id: str,
        app_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamStopLivestreamingAMeetingResponse:
        """
        Stops the active livestream of a meeting associated with the given meeting ID.
        Retreive the meeting ID using the `Create a meeting` API.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        if not meeting_id:
            raise ValueError(f"Expected a non-empty value for `meeting_id` but received {meeting_id!r}")
        return self._post(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/meetings/{meeting_id}/active-livestream/stop",
                account_id=account_id,
                app_id=app_id,
                meeting_id=meeting_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LivestreamStopLivestreamingAMeetingResponse,
        )


class AsyncLivestreamsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncLivestreamsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncLivestreamsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncLivestreamsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncLivestreamsResourceWithStreamingResponse(self)

    async def create_independent_livestream(
        self,
        app_id: str,
        *,
        account_id: str,
        name: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamCreateIndependentLivestreamResponse:
        """
        Creates a livestream for the given App ID and returns ingest server, stream key,
        and playback URL. You can pass custom input to the ingest server and stream key,
        and freely distribute the content using the playback URL on any player that
        supports HLS/LHLS.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          name: Name of the livestream

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        return await self._post(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/livestreams", account_id=account_id, app_id=app_id
            ),
            body=await async_maybe_transform(
                {"name": name},
                livestream_create_independent_livestream_params.LivestreamCreateIndependentLivestreamParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LivestreamCreateIndependentLivestreamResponse,
        )

    async def get_active_livestreams_for_livestream_id(
        self,
        livestream_id: str,
        *,
        account_id: str,
        app_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamGetActiveLivestreamsForLivestreamIDResponse:
        """Returns details of all active livestreams for the given livestream ID.

        Retreive
        the livestream ID using the `Start livestreaming a meeting` API.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        if not livestream_id:
            raise ValueError(f"Expected a non-empty value for `livestream_id` but received {livestream_id!r}")
        return await self._get(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/livestreams/{livestream_id}/active-livestream-session",
                account_id=account_id,
                app_id=app_id,
                livestream_id=livestream_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LivestreamGetActiveLivestreamsForLivestreamIDResponse,
        )

    async def get_all_livestreams(
        self,
        app_id: str,
        *,
        account_id: str,
        end_time: Union[str, datetime] | Omit = omit,
        exclude_meetings: bool | Omit = omit,
        page_no: int | Omit = omit,
        per_page: int | Omit = omit,
        sort_order: Literal["ASC", "DSC"] | Omit = omit,
        start_time: Union[str, datetime] | Omit = omit,
        status: Literal["LIVE", "IDLE", "ERRORED", "INVOKED"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamGetAllLivestreamsResponse:
        """Returns details of livestreams associated with the given App ID.

        It includes
        livestreams created by your App and RealtimeKit meetings that are livestreamed
        by your App. If you only want details of livestreams created by your App and not
        RealtimeKit meetings, you can use the `exclude_meetings` query parameter.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          end_time: Specify the end time range in ISO format to access the live stream.

          exclude_meetings: Exclude the RealtimeKit meetings that are livestreamed.

          page_no: The page number from which you want your page search results to be displayed.

          per_page: Number of results per page.

          sort_order: Specifies the sorting order for the results.

          start_time: Specify the start time range in ISO format to access the live stream.

          status: Specifies the status of the operation.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        return await self._get(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/livestreams", account_id=account_id, app_id=app_id
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "end_time": end_time,
                        "exclude_meetings": exclude_meetings,
                        "page_no": page_no,
                        "per_page": per_page,
                        "sort_order": sort_order,
                        "start_time": start_time,
                        "status": status,
                    },
                    livestream_get_all_livestreams_params.LivestreamGetAllLivestreamsParams,
                ),
            ),
            cast_to=LivestreamGetAllLivestreamsResponse,
        )

    async def get_livestream_analytics_complete(
        self,
        app_id: str,
        *,
        account_id: str,
        end_time: Union[str, datetime] | Omit = omit,
        start_time: Union[str, datetime] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamGetLivestreamAnalyticsCompleteResponse:
        """
        Returns livestream analytics for the specified time range.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          end_time: Specify the end time range in ISO format to access the livestream analytics.

          start_time: Specify the start time range in ISO format to access the livestream analytics.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        return await self._get(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/analytics/livestreams/overall",
                account_id=account_id,
                app_id=app_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "end_time": end_time,
                        "start_time": start_time,
                    },
                    livestream_get_livestream_analytics_complete_params.LivestreamGetLivestreamAnalyticsCompleteParams,
                ),
            ),
            cast_to=LivestreamGetLivestreamAnalyticsCompleteResponse,
        )

    async def get_livestream_session_details_for_session_id(
        self,
        livestream_session_id: str,
        *,
        account_id: str,
        app_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamGetLivestreamSessionDetailsForSessionIDResponse:
        """Returns livestream session details for the given livestream session ID.

        Retrieve
        the `livestream_session_id`using the
        `Fetch livestream session details using a session ID` API.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        if not livestream_session_id:
            raise ValueError(
                f"Expected a non-empty value for `livestream_session_id` but received {livestream_session_id!r}"
            )
        return await self._get(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/livestreams/sessions/{livestream_session_id}",
                account_id=account_id,
                app_id=app_id,
                livestream_session_id=livestream_session_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LivestreamGetLivestreamSessionDetailsForSessionIDResponse,
        )

    async def get_livestream_session_for_livestream_id(
        self,
        livestream_id: str,
        *,
        account_id: str,
        app_id: str,
        page_no: int | Omit = omit,
        per_page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamGetLivestreamSessionForLivestreamIDResponse:
        """
        Returns details of a livestream with sessions for the given livestream ID.
        Retreive the livestream ID using the `Start livestreaming a meeting` API.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          page_no: The page number from which you want your page search results to be displayed.

          per_page: Number of results per page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        if not livestream_id:
            raise ValueError(f"Expected a non-empty value for `livestream_id` but received {livestream_id!r}")
        return await self._get(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/livestreams/{livestream_id}",
                account_id=account_id,
                app_id=app_id,
                livestream_id=livestream_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "page_no": page_no,
                        "per_page": per_page,
                    },
                    livestream_get_livestream_session_for_livestream_id_params.LivestreamGetLivestreamSessionForLivestreamIDParams,
                ),
            ),
            cast_to=LivestreamGetLivestreamSessionForLivestreamIDResponse,
        )

    async def get_meeting_active_livestreams(
        self,
        meeting_id: str,
        *,
        account_id: str,
        app_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamGetMeetingActiveLivestreamsResponse:
        """
        Returns details of all active livestreams for the given meeting ID.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        if not meeting_id:
            raise ValueError(f"Expected a non-empty value for `meeting_id` but received {meeting_id!r}")
        return await self._get(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/meetings/{meeting_id}/active-livestream",
                account_id=account_id,
                app_id=app_id,
                meeting_id=meeting_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LivestreamGetMeetingActiveLivestreamsResponse,
        )

    async def get_org_analytics(
        self,
        app_id: str,
        *,
        account_id: str,
        end_date: str | Omit = omit,
        start_date: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamGetOrgAnalyticsResponse:
        """
        Returns day-wise session and recording analytics data of an App for the
        specified time range start_date to end_date. If start_date and end_date are not
        provided, the default time range is set from 30 days ago to the current date.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          end_date: end date in YYYY-MM-DD format

          start_date: start date in YYYY-MM-DD format

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        return await self._get(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/analytics/daywise", account_id=account_id, app_id=app_id
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "end_date": end_date,
                        "start_date": start_date,
                    },
                    livestream_get_org_analytics_params.LivestreamGetOrgAnalyticsParams,
                ),
            ),
            cast_to=LivestreamGetOrgAnalyticsResponse,
        )

    async def start_livestreaming_a_meeting(
        self,
        meeting_id: str,
        *,
        account_id: str,
        app_id: str,
        name: Optional[str] | Omit = omit,
        video_config: livestream_start_livestreaming_a_meeting_params.VideoConfig | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamStartLivestreamingAMeetingResponse:
        """Starts livestream of a meeting associated with the given meeting ID.

        Retreive
        the meeting ID using the `Create a meeting` API.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        if not meeting_id:
            raise ValueError(f"Expected a non-empty value for `meeting_id` but received {meeting_id!r}")
        return await self._post(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/meetings/{meeting_id}/livestreams",
                account_id=account_id,
                app_id=app_id,
                meeting_id=meeting_id,
            ),
            body=await async_maybe_transform(
                {
                    "name": name,
                    "video_config": video_config,
                },
                livestream_start_livestreaming_a_meeting_params.LivestreamStartLivestreamingAMeetingParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LivestreamStartLivestreamingAMeetingResponse,
        )

    async def stop_livestreaming_a_meeting(
        self,
        meeting_id: str,
        *,
        account_id: str,
        app_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LivestreamStopLivestreamingAMeetingResponse:
        """
        Stops the active livestream of a meeting associated with the given meeting ID.
        Retreive the meeting ID using the `Create a meeting` API.

        Args:
          account_id: The account identifier tag.

          app_id: The app identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not app_id:
            raise ValueError(f"Expected a non-empty value for `app_id` but received {app_id!r}")
        if not meeting_id:
            raise ValueError(f"Expected a non-empty value for `meeting_id` but received {meeting_id!r}")
        return await self._post(
            path_template(
                "/accounts/{account_id}/realtime/kit/{app_id}/meetings/{meeting_id}/active-livestream/stop",
                account_id=account_id,
                app_id=app_id,
                meeting_id=meeting_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LivestreamStopLivestreamingAMeetingResponse,
        )


class LivestreamsResourceWithRawResponse:
    def __init__(self, livestreams: LivestreamsResource) -> None:
        self._livestreams = livestreams

        self.create_independent_livestream = to_raw_response_wrapper(
            livestreams.create_independent_livestream,
        )
        self.get_active_livestreams_for_livestream_id = to_raw_response_wrapper(
            livestreams.get_active_livestreams_for_livestream_id,
        )
        self.get_all_livestreams = to_raw_response_wrapper(
            livestreams.get_all_livestreams,
        )
        self.get_livestream_analytics_complete = to_raw_response_wrapper(
            livestreams.get_livestream_analytics_complete,
        )
        self.get_livestream_session_details_for_session_id = to_raw_response_wrapper(
            livestreams.get_livestream_session_details_for_session_id,
        )
        self.get_livestream_session_for_livestream_id = to_raw_response_wrapper(
            livestreams.get_livestream_session_for_livestream_id,
        )
        self.get_meeting_active_livestreams = to_raw_response_wrapper(
            livestreams.get_meeting_active_livestreams,
        )
        self.get_org_analytics = to_raw_response_wrapper(
            livestreams.get_org_analytics,
        )
        self.start_livestreaming_a_meeting = to_raw_response_wrapper(
            livestreams.start_livestreaming_a_meeting,
        )
        self.stop_livestreaming_a_meeting = to_raw_response_wrapper(
            livestreams.stop_livestreaming_a_meeting,
        )


class AsyncLivestreamsResourceWithRawResponse:
    def __init__(self, livestreams: AsyncLivestreamsResource) -> None:
        self._livestreams = livestreams

        self.create_independent_livestream = async_to_raw_response_wrapper(
            livestreams.create_independent_livestream,
        )
        self.get_active_livestreams_for_livestream_id = async_to_raw_response_wrapper(
            livestreams.get_active_livestreams_for_livestream_id,
        )
        self.get_all_livestreams = async_to_raw_response_wrapper(
            livestreams.get_all_livestreams,
        )
        self.get_livestream_analytics_complete = async_to_raw_response_wrapper(
            livestreams.get_livestream_analytics_complete,
        )
        self.get_livestream_session_details_for_session_id = async_to_raw_response_wrapper(
            livestreams.get_livestream_session_details_for_session_id,
        )
        self.get_livestream_session_for_livestream_id = async_to_raw_response_wrapper(
            livestreams.get_livestream_session_for_livestream_id,
        )
        self.get_meeting_active_livestreams = async_to_raw_response_wrapper(
            livestreams.get_meeting_active_livestreams,
        )
        self.get_org_analytics = async_to_raw_response_wrapper(
            livestreams.get_org_analytics,
        )
        self.start_livestreaming_a_meeting = async_to_raw_response_wrapper(
            livestreams.start_livestreaming_a_meeting,
        )
        self.stop_livestreaming_a_meeting = async_to_raw_response_wrapper(
            livestreams.stop_livestreaming_a_meeting,
        )


class LivestreamsResourceWithStreamingResponse:
    def __init__(self, livestreams: LivestreamsResource) -> None:
        self._livestreams = livestreams

        self.create_independent_livestream = to_streamed_response_wrapper(
            livestreams.create_independent_livestream,
        )
        self.get_active_livestreams_for_livestream_id = to_streamed_response_wrapper(
            livestreams.get_active_livestreams_for_livestream_id,
        )
        self.get_all_livestreams = to_streamed_response_wrapper(
            livestreams.get_all_livestreams,
        )
        self.get_livestream_analytics_complete = to_streamed_response_wrapper(
            livestreams.get_livestream_analytics_complete,
        )
        self.get_livestream_session_details_for_session_id = to_streamed_response_wrapper(
            livestreams.get_livestream_session_details_for_session_id,
        )
        self.get_livestream_session_for_livestream_id = to_streamed_response_wrapper(
            livestreams.get_livestream_session_for_livestream_id,
        )
        self.get_meeting_active_livestreams = to_streamed_response_wrapper(
            livestreams.get_meeting_active_livestreams,
        )
        self.get_org_analytics = to_streamed_response_wrapper(
            livestreams.get_org_analytics,
        )
        self.start_livestreaming_a_meeting = to_streamed_response_wrapper(
            livestreams.start_livestreaming_a_meeting,
        )
        self.stop_livestreaming_a_meeting = to_streamed_response_wrapper(
            livestreams.stop_livestreaming_a_meeting,
        )


class AsyncLivestreamsResourceWithStreamingResponse:
    def __init__(self, livestreams: AsyncLivestreamsResource) -> None:
        self._livestreams = livestreams

        self.create_independent_livestream = async_to_streamed_response_wrapper(
            livestreams.create_independent_livestream,
        )
        self.get_active_livestreams_for_livestream_id = async_to_streamed_response_wrapper(
            livestreams.get_active_livestreams_for_livestream_id,
        )
        self.get_all_livestreams = async_to_streamed_response_wrapper(
            livestreams.get_all_livestreams,
        )
        self.get_livestream_analytics_complete = async_to_streamed_response_wrapper(
            livestreams.get_livestream_analytics_complete,
        )
        self.get_livestream_session_details_for_session_id = async_to_streamed_response_wrapper(
            livestreams.get_livestream_session_details_for_session_id,
        )
        self.get_livestream_session_for_livestream_id = async_to_streamed_response_wrapper(
            livestreams.get_livestream_session_for_livestream_id,
        )
        self.get_meeting_active_livestreams = async_to_streamed_response_wrapper(
            livestreams.get_meeting_active_livestreams,
        )
        self.get_org_analytics = async_to_streamed_response_wrapper(
            livestreams.get_org_analytics,
        )
        self.start_livestreaming_a_meeting = async_to_streamed_response_wrapper(
            livestreams.start_livestreaming_a_meeting,
        )
        self.stop_livestreaming_a_meeting = async_to_streamed_response_wrapper(
            livestreams.stop_livestreaming_a_meeting,
        )
